==> haskell-hspec-api-2.11.4-4.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.4
visibility:           public
id:                   hspec-api-2.11.4-IJhYXPLNTHzIe1897BrL5s
key:                  hspec-api-2.11.4-IJhYXPLNTHzIe1897BrL5s
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  a436dc8b5e20cf58d36df4d7f0e2f3a8
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:       Test.Hspec.Api.Format.V1.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.4-IJhYXPLNTHzIe1897BrL5s
depends:
    base-4.18.2.1 hspec-core-2.11.4-1HkLPyupJ0H3VqtAEeRZWL
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-api-2.11.4-5-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.4
visibility:           public
id:                   hspec-api-2.11.4-9yghyKpx2kBDnkTc8dVOGD
key:                  hspec-api-2.11.4-9yghyKpx2kBDnkTc8dVOGD
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  4c4c7dd909b5fb3810ddc1cf2dbe885d
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:       Test.Hspec.Api.Format.V1.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-api-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.4-9yghyKpx2kBDnkTc8dVOGD
depends:
    base-4.18.2.1 hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
